@@ -3,7 +3,7 @@ package Meow;
 use 5.006;
 use strict;
 use warnings;
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 require XSLoader;
 XSLoader::load('Meow', $VERSION);
@@ -20,7 +20,7 @@ Meow - Object ฅ^•ﻌ•^ฅ Orientation
 
 =head1 VERSION
 
-Version 0.16
+Version 0.17
 
 =cut
 
@@ -191,7 +191,7 @@ Constructs a new object, applying defaults, coercions, triggers, and builders as
 	{
 		package Foo::Extends::Meow;
 
-		use Moo;
+		use Meow;
 		extends qw/Foo::Meow/;
 
 		1;
@@ -218,7 +218,7 @@ Constructs a new object, applying defaults, coercions, triggers, and builders as
 	}
 
 
-	my $r = timethese(1000000, {
+	my $r = timethese(10000000, {
 		'Moo' => sub {
 			my $foo = Foo::Extends::Moo->new();
 			$foo->one;
@@ -233,6 +233,11 @@ Constructs a new object, applying defaults, coercions, triggers, and builders as
 			my $foo = Foo::Extends::Mouse->new();
 			$foo->one;
 			$foo->two;
+		},
+		'Marlin' => sub {
+			my $foo = Foo::Extends::Marlin->new();
+			$foo->one;
+			$foo->two;
 		}
 	});
 
@@ -240,16 +245,16 @@ Constructs a new object, applying defaults, coercions, triggers, and builders as
 
 ...
 
-	Benchmark: timing 1000000 iterations of Marlin, Meow, Moo, Mouse...
-	    Marlin: 0.911942 wallclock secs ( 0.89 usr +  0.02 sys =  0.91 CPU) @ 1098901.10/s (n=1000000)
-	      Meow: 1.64158 wallclock secs ( 1.63 usr +  0.02 sys =  1.65 CPU) @ 606060.61/s (n=1000000)
-	       Moo: 1.64699 wallclock secs ( 1.64 usr +  0.00 sys =  1.64 CPU) @ 609756.10/s (n=1000000)
-	     Mouse: 0.889783 wallclock secs ( 0.88 usr +  0.00 sys =  0.88 CPU) @ 1136363.64/s (n=1000000)
-		    Rate   Meow    Moo Marlin  Mouse
-	Meow    606061/s     --    -1%   -45%   -47%
-	Moo     609756/s     1%     --   -45%   -46%
-	Marlin 1098901/s    81%    80%     --    -3%
-	Mouse  1136364/s    87%    86%     3%     --
+	Benchmark: timing 10,000,000 iterations of Marlin, Meow, Moo, Mouse...
+	    Marlin:  1 wallclock secs ( 2.17 usr +  0.05 sys =  2.22 CPU) @ 4504504.50/s (n=10000000)
+	      Meow:  5 wallclock secs ( 4.51 usr +  0.07 sys =  4.58 CPU) @ 2183406.11/s (n=10000000)
+	       Moo: 10 wallclock secs (11.47 usr +  0.04 sys = 11.51 CPU) @ 868809.73/s (n=10000000)
+	     Mouse:  5 wallclock secs ( 6.13 usr +  0.02 sys =  6.15 CPU) @ 1626016.26/s (n=10000000)
+		    Rate    Moo  Mouse   Meow Marlin
+	Moo     868810/s     --   -47%   -60%   -81%
+	Mouse  1626016/s    87%     --   -26%   -64%
+	Meow   2183406/s   151%    34%     --   -52%
+	Marlin 4504505/s   418%   177%   106%     --
 
 Note: Type::Tiny::XS is installed and so is the other optional XS dependancies for Moo.
 
